package exo4;


import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.Socket;
import java.net.SocketTimeoutException;


/**
 * A simple network client that establishes a network connection to a specified
 * port on a specified host, send an optional message across the connection,
 * reads the response from the server and exits. A suitable client for simple
 * network services like the daytime or finger.
 */
public class Connect {
  public static void main(String[] args) {
    try { // Handle exceptions below
      // Get our command-line arguments
      String hostname = args[0];
      int port = Integer.parseInt(args[1]);
      String message = "";

      // Create a Socket connected to the specified host and port.
      Socket s = new Socket(hostname, port);

	  Sender sender = new Sender(s);
	  sender.start();
	  InputStreamReader reader = new InputStreamReader(System.in) ;
	  BufferedReader in = new BufferedReader(reader);
	  while(!message.equals("Quit")) {
		  message = in.readLine();

		  // Get the socket output stream and wrap a PrintWriter around it
		  PrintWriter out = new PrintWriter(s.getOutputStream());
		  
		  // Sent the specified message through the socket to the server.
		  out.print(message + "\r\n");
		  
		  out.flush(); // Send it now.
	  }

      s.close(); // Close the socket
    } catch (IOException e) { // Handle IO and network exceptions here
      System.err.println(e);
    } catch (NumberFormatException e) { // Bad port number
      System.err.println("You must specify the port as a number");
    } catch (ArrayIndexOutOfBoundsException e) { // wrong # of args
      System.err.println("Usage: Connect <hostname> <port> message...");
    }
  }
}